# Query
```{include} query/examples.md
:start-after: example minimal start
:end-before: example minimal end
```
```{include} query/overview.md
```

## Reusing Query Results

```{include} query/examples.md
:start-after: example reuse query results start
:end-before: example reuse query results end
```